@@ -1,6 +1,6 @@
 ### -*- coding: utf-8 -*- #############################################
 # Developed by Maksym Polshcha (maxp@sterch.net)
-# All right reserved, 2012
+# All right reserved, 2012, 2013
 #######################################################################
 
 """Interfaces for the ZCA based sterch.scrapingtools package
@@ -9,8 +9,12 @@
 __author__  = "Polscha Maxim (maxp@sterch.net)"
 __license__ = "ZPL"
 
+from zope.interface import Interface
 from zope.component.interfaces import IFactory
 
+class IConfig(Interface):
+    """ Base config class """
+
 class IHTTPHeadersFactory(IFactory):
     """ Factory of HTTP headers. See .headers.getheaders to find out format """
 
